
import gwinc
import kagra_sensitivity

from gwinc_kagra import gwinc_kagra

import numpy as np
import matplotlib.pyplot as plt

from numpy import pi

from optparse import OptionParser

def kagra_ref(options):
    phidet=pi/180*90   # detune phase
    xi=pi/180*90       # homodyne phase
    rSRM=0.92          # amplitude reflectivity of SRM
    Tm=22              # temperature at TM [k]
    SQZ=0
    FC =0

    if options.RSE=='DRSE':          #detuned RSE
    	phidet = pi/180*86.5   
        xi     = pi/180*135.1      
    elif options.RSE=='BRSEhomo':    #broadband RSE with homodyne
    	phidet = pi/180*90
     	xi     = pi/180*119.1
    elif options.RSE=='BRSE':        #broadband RSE without homodyne
      	phidet = pi/180*90
      	xi     = pi/180*90
    elif options.RSE=='BRSEsqz':     #broadband RSE with squeezing
      	phidet = pi/180*90
      	xi     = pi/180*90
        SQZ    =  6
        FC     = 30
    else:
        print 'Unknown RSE: ',options.RSE
    
    nn = kagra_sensitivity.sensitivity(phidet,xi,rSRM,Tm,SQZ=SQZ,FC=FC)
    return nn

def pname(name0):
    if name0 == 'htotal':
        return 'Total'
    if name0 == 'hseis':
        return 'Seismic'
    if name0 == 'hsusp':
        return 'Suspension Thermal'
    if name0 == 'hmir':
        return 'Coating Brownian'
    if name0 == 'hsh':
        return 'Quantum Vacuum'
    return ''

def cmp(fig, n1, n0, name1 = 'Total', name0 = 'htotal', ylim = 0.01):
    nn0  = n0[name0]
    nn1  = n1[name1]

    if name0 == 'hseis':
        nn1 = nn1+n1['Newtonian Gravity']
    if name0 == 'hmir':
        nn1 = nn1+n1['Substrate Brownian']+n1['Substrate Thermo-Elastic']

    nn1  = np.sqrt(nn1)
    freq = n0['f']  #n1['Freq']

    lb1 = 'gwinc_kagra'
    lb2 = 'kagra_sensitivity'

    ax  = fig.add_subplot(2, 1, 1)
    ax.loglog(freq, nn1, color='red',  label=lb1, linestyle='-')
    ax.loglog(freq, nn0, color='blue', label=lb2, linestyle=':', linewidth=3)
    ax.legend(fontsize=13)

    ax.xaxis.grid(True)
    ax.yaxis.grid(True)
    ax.set_xlim([5,5000])
    ax.set_ylim([1e-24, 5e-21])
    ax.set_ylabel(u"Strain [1/\u221AHz]")
    ax.set_xticklabels([])

    ax  = fig.add_subplot(2, 1, 2)
    ax.semilogx(freq, nn1/nn0-1)
    ax.xaxis.grid(True)
    ax.yaxis.grid(True)
    ax.set_xlim([5,5000])
    ax.set_ylim([-ylim, ylim])
    ax.set_xlabel('Frequency [Hz]')
    ax.set_ylabel("Relative difference")


parser = OptionParser()
parser.add_option("--RSE", metavar = "RSE", default = "DRSE", \
                      help = "Specify RSE configuration (DRSE,BRSE,BRSEhomo)")
parser.add_option("--plot", metavar = "name", default = "htotal", \
                      help = "Plot specified noise component "\
                      "(htotal,hseis,hsusp,hmir,hsh)")
parser.add_option("--ylim", metavar = "value", default = "0.01", \
                      help = "Vertical range for the comparison plot")

(options, args) = parser.parse_args()

yaml = 'kagra/bKAGRA_'+options.RSE+'.yaml'
ifo  = gwinc.load_ifo(yaml)

n0 = kagra_ref(options)
n1 = gwinc_kagra(n0['f'], ifo)

fig = plt.figure(figsize=(4,6), dpi=100, facecolor='white')
plt.subplots_adjust(top=0.98, left=0.18, right=0.98,\
                    wspace=0.05, hspace=0.07)

cmp(fig, n1, n0, pname(options.plot), options.plot, float(options.ylim))
fig.show()
